@@ -15,17 +15,17 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'BUILDPYTHON': 'python.exe',
  'CC': 'gcc',
  'CCSHARED': '',
- 'CFLAGS': '-fno-strict-aliasing -ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/usr/src/ports/python2/python2-2.7.16-1.x86_64/build=/usr/src/debug/python2-2.7.16-1 -fdebug-prefix-map=/usr/src/ports/python2/python2-2.7.16-1.x86_64/src/Python-2.7.16=/usr/src/debug/python2-2.7.16-1 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
+ 'CFLAGS': '-fno-strict-aliasing -ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/pub/devel/python/python27/python2-2.7.18-1.i686/build=/usr/src/debug/python2-2.7.18-1 -fdebug-prefix-map=/pub/devel/python/python27/python2-2.7.18-1.i686/src/Python-2.7.18=/usr/src/debug/python2-2.7.18-1 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'CFLAGSFORSHARED': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--srcdir=/usr/src/ports/python2/python2-2.7.16-1.x86_64/src/Python-2.7.16' '--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' '--sysconfdir=/etc' '--docdir=/usr/share/doc/python2' '--htmldir=/usr/share/doc/python2/html' '-C' '--enable-shared' '--enable-ipv6' '--with-dbmliborder=gdbm' '--with-libc=' '--with-libm=' '--with-system-ffi' '--with-system-expat' 'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' 'CFLAGS=-ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/usr/src/ports/python2/python2-2.7.16-1.x86_64/build=/usr/src/debug/python2-2.7.16-1 -fdebug-prefix-map=/usr/src/ports/python2/python2-2.7.16-1.x86_64/src/Python-2.7.16=/usr/src/debug/python2-2.7.16-1' 'LDFLAGS= -L.' 'LIBS=' 'CPPFLAGS='",
+ 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python27/python2-2.7.18-1.i686/src/Python-2.7.18' '--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' '--sysconfdir=/etc' '--docdir=/usr/share/doc/python2' '--htmldir=/usr/share/doc/python2/html' '-C' '--enable-shared' '--enable-ipv6' '--with-dbmliborder=gdbm' '--with-libc=' '--with-libm=' '--with-system-ffi' '--with-system-expat' 'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' 'CFLAGS=-ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/pub/devel/python/python27/python2-2.7.18-1.i686/build=/usr/src/debug/python2-2.7.18-1 -fdebug-prefix-map=/pub/devel/python/python27/python2-2.7.18-1.i686/src/Python-2.7.18=/usr/src/debug/python2-2.7.18-1' 'LDFLAGS= -L.' 'LIBS=' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python2.7',
  'COREPYTHONPATH': ':plat-cygwin:lib-tk:lib-old',
- 'COVERAGE_INFO': '/usr/src/ports/python2/python2-2.7.16-1.x86_64/build/coverage.info',
- 'COVERAGE_REPORT': '/usr/src/ports/python2/python2-2.7.16-1.x86_64/build/lcov-report',
+ 'COVERAGE_INFO': '/pub/devel/python/python27/python2-2.7.18-1.i686/build/coverage.info',
+ 'COVERAGE_REPORT': '/pub/devel/python/python27/python2-2.7.18-1.i686/build/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
- 'CPPFLAGS': '-I. -IInclude -I/usr/src/ports/python2/python2-2.7.16-1.x86_64/src/Python-2.7.16/Include',
+ 'CPPFLAGS': '-I. -IInclude -I/pub/devel/python/python27/python2-2.7.18-1.i686/src/Python-2.7.18/Include',
  'CXX': 'g++',
  'C_THREADS': 0,
  'DESTDIRS': '/usr /usr/lib /usr/lib/python2.7 /usr/lib/python2.7/lib-dynload',
@@ -185,8 +185,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 0,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 0,
+ 'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
  'HAVE_LGAMMA': 1,
  'HAVE_LIBDL': 1,
@@ -356,7 +357,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'x86_64-pc-cygwin',
+ 'HOST_GNU_TYPE': 'i686-pc-cygwin',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python2.7 /usr/include/python2.7',
  'INCLUDEDIR': '/usr/include',
@@ -385,7 +386,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'LIBPL': '/usr/lib/python2.7/config',
  'LIBRARY': 'libpython2.7.a',
  'LIBRARY_OBJS': '\\',
- 'LIBS': '-ldl',
+ 'LIBS': '-lintl -ldl',
  'LIBSUBDIRS': 'lib-tk lib-tk/test lib-tk/test/test_tkinter \\',
  'LINKCC': 'gcc',
  'LINKFORSHARED': '',
@@ -404,7 +405,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/usr/src/ports/python2/python2-2.7.16-1.x86_64/src/Python-2.7.16/Modules/makesetup',
+ 'MAKESETUP': '/pub/devel/python/python27/python2-2.7.18-1.i686/src/Python-2.7.18/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
  'MKDIR_P': '/usr/bin/mkdir -p',
@@ -452,7 +453,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHON_FOR_REGEN': 'python2.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/usr/src/ports/python2/python2-2.7.16-1.x86_64/build=/usr/src/debug/python2-2.7.16-1 -fdebug-prefix-map=/usr/src/ports/python2/python2-2.7.16-1.x86_64/src/Python-2.7.16=/usr/src/debug/python2-2.7.16-1 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. -IInclude -I/usr/src/ports/python2/python2-2.7.16-1.x86_64/src/Python-2.7.16/Include  -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/pub/devel/python/python27/python2-2.7.18-1.i686/build=/usr/src/debug/python2-2.7.18-1 -fdebug-prefix-map=/pub/devel/python/python27/python2-2.7.18-1.i686/src/Python-2.7.18=/usr/src/debug/python2-2.7.18-1 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. -IInclude -I/pub/devel/python/python27/python2-2.7.18-1.i686/src/Python-2.7.18/Include  -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_UNICODE_TYPE': 'wchar_t',
@@ -469,7 +470,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-ldl',
+ 'SHLIBS': '-lintl -ldl',
  'SHLIB_EXT': '".dll"',
  'SIGNAL_OBJS': '',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
@@ -478,22 +479,22 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 16,
+ 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG_DOUBLE': 12,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
- 'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_SIZE_T': 4,
+ 'SIZEOF_TIME_T': 4,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 2,
  'SIZEOF__BOOL': 1,
  'SO': '.dll',
- 'SRCDIRS': 'Parser Objects Python Modules',
- 'SRC_GDB_HOOKS': '/usr/src/ports/python2/python2-2.7.16-1.x86_64/src/Python-2.7.16/Tools/gdb/libpython.py',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io',
+ 'SRC_GDB_HOOKS': '/pub/devel/python/python27/python2-2.7.18-1.i686/src/Python-2.7.18/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRINGLIB_HEADERS': '\\',
@@ -506,7 +507,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TCLTK_LIBS': '',
  'TESTOPTS': '-l',
  'TESTPATH': '',
- 'TESTPROG': '/usr/src/ports/python2/python2-2.7.16-1.x86_64/src/Python-2.7.16/Lib/test/regrtest.py',
+ 'TESTPROG': '/pub/devel/python/python27/python2-2.7.18-1.i686/src/Python-2.7.18/Lib/test/regrtest.py',
  'TESTPYTHON': './python.exe -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
@@ -519,7 +520,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'USE_TOOLBOX_OBJECT_GLUE': 0,
  'VA_LIST_IS_ARRAY': 0,
  'VERSION': '2.7',
- 'VPATH': '/usr/src/ports/python2/python2-2.7.16-1.x86_64/src/Python-2.7.16',
+ 'VPATH': '/pub/devel/python/python27/python2-2.7.18-1.i686/src/Python-2.7.18',
  'WANT_SIGFPE_HANDLER': 0,
  'WANT_WCTYPE_FUNCTIONS': 0,
  'WINDOW_HAS_FLAGS': 0,
@@ -531,13 +532,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_THREAD': 1,
  'WITH_TSC': 0,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 0,
+ 'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/src/ports/python2/python2-2.7.16-1.x86_64/build',
- 'abs_srcdir': '/usr/src/ports/python2/python2-2.7.16-1.x86_64/src/Python-2.7.16',
- 'build': 'x86_64-pc-cygwin',
+ 'abs_builddir': '/pub/devel/python/python27/python2-2.7.18-1.i686/build',
+ 'abs_srcdir': '/pub/devel/python/python27/python2-2.7.18-1.i686/src/Python-2.7.18',
+ 'build': 'i686-pc-cygwin',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
- 'host': 'x86_64-pc-cygwin',
+ 'host': 'i686-pc-cygwin',
  'prefix': '/usr',
- 'srcdir': '/usr/src/ports/python2/python2-2.7.16-1.x86_64/src/Python-2.7.16'}
+ 'srcdir': '/pub/devel/python/python27/python2-2.7.18-1.i686/src/Python-2.7.18'}
